/* eslint-disable no-undef */
// 注册名为 imageUpload 的插件
CKEDITOR.plugins.add('imageUpload', {
  init: function(editor) {
    // 添加工具栏按钮
    editor.ui.addButton('imageUpload', {
      icon: `${this.path}icon.png`,
      label: 'upload',
      command: 'imageUpload'
    });
    // 点击按钮时执行：选择本地图片
    editor.addCommand('imageUpload', {
      exec: function() {
        const $fileInput = document.createElement('input');
        $fileInput.type = 'file';
        $fileInput.accept = 'image/*';
        $fileInput.click();
        $fileInput.addEventListener('change', e => {
          const file = $fileInput.files[0];
          mxImageUpload(file);
        });
      }
    });
    // 粘贴时执行：拦截图片的默认操作
    editor.on('paste', e => {
      const file = e.data.dataTransfer.getFile(0);
      if (file) {
        e.stop();
        mxImageUpload(file);
      }
    });
    // 上传到傲游服务器
    function mxImageUpload(file) {
      const fileReader = new FileReader();
      fileReader.readAsDataURL(file);
      fileReader.onload = function() {
        // 区分页面
        if (location.protocol !== 'chrome:') {
          // 本地测试
          console.log('插入图片');
          editor.insertHtml(`<img src="${this.result}" />`);
        } else {
          let id;
          switch (location.host) {
            case 'note': // 傲游笔记
              id = cache.curDetail.uuid;
              break;
            case 'quick-note': // 极简笔记
              id = app.noteActiveID;
              break;
            case 'sidebar-note': // 侧边栏笔记
              id = app.treeActiveItem.uuid;
              break;
          }
          api
            .uploadImage({
              id,
              type: file.type.split('/').pop(),
              img: this.result.split(',').pop()
            })
            .then(data => {
              console.log('upload success');
              editor.insertHtml(`<img src="${data.path}" />`);
            });
        }
      };
    }
  }
});
